<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Privilegi dell'utente":  			$messaggio = "Anv&auml;ndarr&auml;ttigheter"; break;
case "Privilegi <b>globali</b>":  		$messaggio = "<b>Globala</b> r&auml;ttigheter"; break;
case "Modifica delle proprie personalizzazioni":	$messaggio = "&Auml;ndra hans/hennes egna anpassningar"; break;
case "Si":  					$messaggio = "Ja"; break;
case "No":  					$messaggio = "Nej"; break;
case "Inserimento di nuovi clienti":  		$messaggio = "Infoga nya kunder"; break;
case "Possibilità di vedere ed utilizzare nelle prenotazioni i clienti già inseriti":	$messaggio = "M&ouml;jlighet att se och anv&auml;nda i bokningar kunder redan har infogat"; break;
case "Solo":  					$messaggio = "Endast"; break;
case "i propri":  				$messaggio = "hans/hennes egna"; break;
case "Modifica e cancellazione dei clienti già inseriti":  	$messaggio = "&Auml;ndra och ta bort redan infogade kunder"; break;
case "dei propri":  				$messaggio = "hans/hennes egna"; break;
case "Inserire in tutti i cognomi dei clienti inseriti da questo utente":	$messaggio = "Infoga f&ouml;r alla kunder efternamn infogade av den h&auml;r anv&auml;ndaren"; break;
case "Un prefisso":  				$messaggio = "Ett prefix"; break;
case "Un suffisso":  				$messaggio = "Ett suffix"; break;
case "Niente":  				$messaggio = "Ingenting"; break;
case "Modifica i privilegi globali":  		$messaggio = "&Auml;ndra globala r&auml;ttigheter"; break;
case "Privilegi per l'anno":			$messaggio = "R&auml;ttigheter f&ouml;r &aring;r"; break;
case "Anno disattivato":  			$messaggio = "&Aring;r avaktiverat"; break;
case "Attiva":  				$messaggio = "Aktivera"; break;
case "Anno attivato":  				$messaggio = "&Aring;r aktiverat"; break;
case "Disattiva":  				$messaggio = "Avaktivera"; break;
case "Prenotazioni inseribili solo nei periodi della regola di assegnazione 1 con le motivazioni selezionate":	$messaggio = "Bokningar infogningsbara endast under perioder tillh&ouml;rande tilldelningsregel 1 med valda motiveringar"; break;
case "nessuna":  				$messaggio = "inga"; break;
case "Applica la regola 1":  			$messaggio = "Till&auml;mpa regel 1"; break;
case "Sempre":  				$messaggio = "Alltid"; break;
case "Solo per regole non selezionate":  	$messaggio = "Endast f&ouml;r icke valda regler"; break;
case "Mai":  					$messaggio = "Aldrig"; break;
case "Mai, ma non spostare altre prenotazioni in periodi delle regole non selezionate se non vi si possono inserire prenotazioni":	$messaggio = "Aldrig,  men flytta inte andra bokningar under perioder som tillh&ouml;r icke valda regler om det inte &auml;r till&aring;tet att infoga bokningar d&auml;r"; break;
case "Permetti l'uso di tutte le <i>tariffe</i> nell'inserimento e modifica delle prenotazioni":	$messaggio = "Till&aring;t anv&auml;ndandet av alla <i>priser</i> n&auml;r bokningar infogas och &auml;ndras"; break;
case "Permetti l'uso solo delle <i>tariffe</i> selezionate nell'inserimento e modifica delle prenotazioni":	$messaggio = "Till&aring;t anv&auml;ndandet av endast de valda <i>priserna</i> n&auml;r bokningar infogas och &auml;ndras"; break;
case "tariffa":  				$messaggio = "pris"; break;
case "Permetti l'uso di tutti i <i>costi aggiuntivi</i> nell'inserimento e modifica delle prenotazioni":	$messaggio = "Till&aring;t anv&auml;ndandet av alla <i>extrakostnader</i> n&auml;r bokningar infogas och &auml;ndras"; break;
case "Permetti l'uso solo dei <i>costi aggiuntivi</i> selezionati nell'inserimento e modifica delle prenotazioni":	$messaggio = "Till&aring;t anv&auml;ndandet av endast valda <i>extrakostnader</i> n&auml;r bokningar infogas och &auml;ndras"; break;
case "Costo unico":  				$messaggio = "Enkel kostnad"; break;
case "Costo settimanale":  			$messaggio = "Veckolig kostnad"; break;
case "Costo giornaliero":  			$messaggio = "Daglig kostnad"; break;
case "Permetti la visualizzazione di tutti i <i>documenti</i>":	$messaggio = "Till&aring;t visualiseringen av alla <i>dokument</i>"; break;
case "Permetti la visualizzazione solo dei <i>documenti</i> selezionati":	$messaggio = "Till&aring;t visualiseringen av endast valda <i>dokument</i>"; break;
case "documento":  				$messaggio = "dokument"; break;
case "Non permettere l'inserimento di <i>nuove prenotazioni</i>":	$messaggio = "Till&aring;t inte infogning av <i>nya bokningar</i>"; break;
case "Permetti l'inserimento di <i>nuove prenotazioni</i> con le seguenti possibilità":	$messaggio = "Till&aring;t infogning av <i>nya bokningar</i> med f&ouml;ljande m&ouml;jligheter"; break;
case "Possibilità di confermare la prenotazione":	$messaggio = "M&ouml;jlighet att bekr&auml;fta bokningen"; break;
case "Possibilità di inserire uno sconto":  	$messaggio = "M&ouml;jlighet att infoga rabatt"; break;
case "Possibilità di inserire dei costi aggiuntivi":	$messaggio = "M&ouml;jlighet att infoga extrakostnader"; break;
case "Possibilità di inserire il numero di persone":	$messaggio = "M&ouml;jlighet att infoga antalet personer"; break;
case "Possibilità di inserire prenotazioni anche in periodi già iniziati":	$messaggio = "M&ouml;jlighet att infoga bokningar &auml;ven i redan p&aring;b&ouml;rjade perioder"; break;
case "Prenotazioni che possono essere <i>modificate</i>":	$messaggio = "Bokningar som kan <i>&auml;ndras</i>"; break;
case "Tutte":  					$messaggio = "Alla"; break;
case "le proprie":  				$messaggio = "egna"; break;
case "dei suoi gruppi":  			$messaggio = "fr&aring;n hans/hennes grupper"; break;
case "Nessuna":  				$messaggio = "Inga"; break;
case "Possibilità di modificare la data iniziale o finale":	$messaggio = "M&ouml;jlighet att &auml;ndra start- eller slutdatum"; break;
case "Possibilità di modificare la tariffa":  	$messaggio = "M&ouml;jlighet att &auml;ndra priset"; break;
case "Si, con regola 2 a scelta":  		$messaggio = "Ja, med regel 2 som val"; break;
case "Si, sempre con regola 2":  		$messaggio = "Ja, alltid med regel 2"; break;
case "Possibilità di modificare il numero delle persone":	$messaggio = "M&ouml;jlighet att &auml;ndra antalet personer"; break;
case "Possibilità di modificare il commento":  	$messaggio = "M&ouml;jlighet att &auml;ndra kommentaren"; break;
case "Possibilità di modificare lo sconto":  	$messaggio = "M&ouml;jlighet att &auml;ndra rabatten"; break;
case "Possibilità di modificare i costi aggiuntivi":	$messaggio = "M&ouml;jlighet att &auml;ndra extrakostnader"; break;
case "Possibilità di modificare i soldi pagati e la conferma":	$messaggio = "M&ouml;jlighet att &auml;ndra betalda pengar och bekr&auml;ftelse"; break;
case "Solo la conferma":  			$messaggio = "Endast bekr&auml;ftelse"; break;
case "Possibilità di modificare prenotazioni già iniziate":	$messaggio = "M&ouml;jlighet att &auml;ndra redan p&aring;b&ouml;rjade bokningar"; break;
case "Prenotazioni non più modificabili dopo un certo numero di ore dopo l'inserzione":	$messaggio = "Bokningar inte &auml;ndringsbara l&auml;ngre efter ett visst antal timmer efter infogandet"; break;
case "ore":  					$messaggio = "timmar"; break;
case "Possibilità di cancellare le prenotazioni":	$messaggio = "M&ouml;jlighet att ta bort bokningar"; break;
case "Solo quelle non iniziate":  		$messaggio = "Endast icke p&aring;b&ouml;rjade bokningar"; break;
case "Prenotazioni non più cancellabili dopo un certo numero di ore dopo l'inserzione":	$messaggio = "Bokningar inte borttagningsbara l&auml;ngre efter ett visst timmar av timmer efter infogandet"; break;
case "Possibilità di inserire e cancellare le <i>spese</i>":	$messaggio = "M&ouml;jlighet att infoga och ta bort <i>betalningar</i>"; break;
case "Possibilità di inserire e cancellare le <i>entrate</i>":	$messaggio = "M&ouml;jlighet att infoga och ta bort <i>kvitton</i>"; break;
case "<i>Sottrarre le entrate</i> dal totale delle prenotazioni":	$messaggio = "<i>Subtrahera kvittona</i> fr&aring;n det totalen f&ouml;r bokningarna"; break;
case "A scelta":  				$messaggio = "Som val"; break;
case "Immettere come <i>persona</i> che inserisce le spese o le entrate":	$messaggio = "Visa som <i>person</i> som infogar betalningar och kvitton"; break;
case "Il nome dell'utente":  			$messaggio = "Anv&auml;ndarnamnet"; break;
case "Chiedere":  				$messaggio = "Fr&aring;ga"; break;
case "Nessuno":  				$messaggio = "Ingen"; break;
case "Possibilità di vedere la <i>tabella dei mesi</i>":	$messaggio = "M&ouml;jlighet att se <i>tabeller med m&aring;nader</i>"; break;
case "Solo con":				$messaggio = "Endast med"; break;
case "prenotazioni proprie":			$messaggio = "egna bokningar"; break;
case "prenotazioni dai suoi gruppi":		$messaggio = "bokningar fr&aring;n hans/hennes grupper"; break;
case "a lui":					$messaggio = "f&ouml;r honom/henne"; break;
case "ai suoi gruppi":				$messaggio = "f&ouml;r hans/hennes grupper"; break;
case "Possibilità di vedere la <i>tabella con tutte le prenotazioni</i>":	$messaggio = "M&ouml;jlighet att se <i>bokningstabellen</i>"; break;
case "Possibilità di vedere le <i>tabelle con le entrate e le uscite</i>":	$messaggio = "M&ouml;jlighet att se <i>tabellen med betalningar och kvitton</i>"; break;
case "entrate/uscite proprie":  		$messaggio = "egna betalningar/kvitton"; break;
case "entrate/uscite dai suoi gruppi":  	$messaggio = "betalningar/kvitton fr&aring;n hans/hennes grupper"; break;
case "Possibilità di vedere la <i>tabella con i periodi e le tariffe</i>":	$messaggio = "M&ouml;jlighet att se <i>tabellen med perider och priser</i>"; break;
case "Solo con tariffe consentite":  		$messaggio = "Endast med till&aring;tna priser"; break;
case "Possibilità di vedere la <i>tabella con le regole di assegnazione</i>":	$messaggio = "M&ouml;jlighet att se <i>tabell med &ouml;verl&aring;telseregler</i>"; break;
case "Solo con regole consentite":  		$messaggio = "Endast med till&aring;tna regler"; break;
case "Modifica i privilegi dell'anno":  	$messaggio = "&Auml;ndra &aring;rsr&auml;ttigheter"; break;
case "Testo del prefisso/suffisso dei clienti":	$messaggio = "Prefix/suffix-text f&ouml;r kunder"; break;
case "Si deve inserire il <div style=\"display: inline; color: red;\">prefisso/suffisso</div> da utilizzare per i clienti dell'utente":	$messaggio = "Du m&aring;ste ange <div style=\"display: inline; color: red;\">prefixet/suffixet</div> att anv&auml;ndas f&ouml;r kunder tillh&ouml;rande anv&auml;ndare"; break;
case "L'utente":  				$messaggio = "Anv&auml;ndaren"; break;
case "potrà modificare le sue <b>personalizzazioni</b>":	$messaggio = "kommer kunna &auml;ndra hans/hennes <b>anpassningar</b>"; break;
case "non potrà più modificare le sue <b>personalizzazioni</b>":	$messaggio = "kommer inte kunna &auml;ndra hans/hennes <b>anpassningar</b> l&auml;ngre"; break;
case "potrà inserire <b>nuovi clienti</b>":  	$messaggio = "kommer kunna l&auml;gga till <b>nya kunder</b>"; break;
case "non potrà più inserire <b>nuovi clienti</b>":	$messaggio = "kommer inte kunna l&auml;gga till <b>nya kunder</b> l&auml;ngre"; break;
case "potrà modificare <b>tutti i clienti</b>":	$messaggio = "kommer kunna &auml;ndra <b>alla kunder</b>"; break;
case "potrà modificare solo i <b>propri clienti</b>":	$messaggio = "kommer kunna &auml;ndra endast hans/hennes <b>egna kunder</b>"; break;
case "e quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "och dom fr&aring;n anv&auml;ndare h&ouml;rande till hans/hennes grupper"; break;
case "non potrà più modificare <b>nessun cliente</b>":	$messaggio = "kommer inte kunna &auml;ndra <b>alla kunder</b> l&auml;ngre"; break;
case "non potrà vedere <b>nessun cliente</b>":	$messaggio = "kommer inte kunna se <b>alla kunder</b>"; break;
case "potrà vedere solo i <b>propri clienti</b>":	$messaggio = "kommer kunna se endast hans/hennes <b>egna kunder</b>"; break;
case "potrà vedere <b>tutti i clienti</b>":  	$messaggio = "kommer kunnda se <b>alla kunder</b>"; break;
case "Verrà aggiunto un <b>prefisso</b> a tutti i cognomi dei clienti inseriti dall'utente":	$messaggio = "Ett <b>prefix</b> kommer l&auml;ggas till till alla kunders efternamn som lagts till av anv&auml;ndaren"; break;
case "Verrà aggiunto un <b>suffisso</b> a tutti i cognomi dei clienti inseriti dall'utente":	$messaggio = "Ett <b>suffix</b> kommer l&auml;ggas till till alla kunders efternamn som l&auml;ggs till av anv&auml;ndaren"; break;
case "Non verrà aggiunto più alcun <b>prefisso/suffisso</b> ai cognomi dei clienti inseriti dall'utente":	$messaggio = "Ett <b>suffix</b> kommer inte l&auml;ngre l&auml;ggast ill till kunders efternamn som l&auml;ggs till av anv&auml;ndaren"; break;
case "Il nuovo testo del <b>prefisso/suffisso</b> dei cognomi dei clienti inseriti dall'utente":	$messaggio = "Den nya <b>prefix/suffix</b>-texten f&ouml;r kundefternamn tillagda av anv&auml;ndaren"; break;
case "sarà":  					$messaggio = "kommer"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Anno <div style=\"display: inline; color: red;\">errato</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Felaktigt</div> &aring;r"; break;
case "Ore in cui si può modificare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Antalet timmar under vilka det &auml;r m&ouml;jligt att &auml;ndra bokningar &auml;r <div style=\"display: inline; color: red;\">felaktigt</div>"; break;
case "Ore in cui si può cancellare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Antalet timmar under vilka det &auml;r m&ouml;jligt att ta bort bokningar &auml;r <div style=\"display: inline; color: red;\">felaktigt</div>"; break;
case "potrà inserire le sue prenotazioni in <b>tutti i periodi</b> del":	$messaggio = "kommer kunna infoga hans/hennes bokningar under <b>alla perioder</b> f&ouml;r"; break;
case "potrà inserire le sue prenotazioni solo nei <b>periodi della regola 1</b> selezionati nel":	$messaggio = "kommer kunna infoga hans/hennes bokningar undder endast <b>perioder tillh&ouml;rande regel 1</b> valda i"; break;
case "Verranno cambiate le motivazioni selezionate della <b>regola 1</b> per l'anno":	$messaggio = "Valda motiveringar f&ouml;r <b>regel 1</b> kommer &auml;ndras f&ouml;r &aring;r"; break;
case "verrà avvisato <b>sempre</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "kommer <b>alltid</b> informeras f&ouml;re infogandet av bokningar under perioder tillh&ouml;rande regel 1 f&ouml;r"; break;
case "verrà avvisato solo quando inserirà prenotazioni nei periodi delle regole 1 <b>non selezionate</b> del":	$messaggio = "kommer endast informeras n&auml;r bokningar infogas under perioder tillh&ouml;rande regel 1 <b>inte valda</b> f&ouml;r"; break;
case "non verrà avvisato <b>mai</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "kommer <b>aldrig</b> informeras n&auml;r bokningar infogas under perioder tillh&ouml;rande regel 1 f&ouml;r"; break;
case "se non vi può inserire prenotazioni":	$messaggio = "om han/hon inte kan infoga bokningar d&auml;r"; break;
case "potrà utilizzare <b>tutte le tariffe</b> del":	$messaggio = "kommer kunna anv&auml;nda <b>alla priser</b> f&ouml;r"; break;
case "potrà utilizzare solo le <b>tariffe selezionate</b> del":	$messaggio = "kommer endast kunna anv&auml;nda <b>valda priser</b> f&ouml;r"; break;
case "Verranno cambiate le <b>tariffe selezionate</b> da utilizzare per l'anno":	$messaggio = "<b>Valda priser</b> kommer &auml;ndras f&ouml;r &aring;r"; break;
case "potrà utilizzare <b>tutti i costi aggiuntivi</b> del":	$messaggio = "kommer kunna anv&auml;nda <b>alla extrakostnader</b> f&ouml;r"; break;
case "potrà utilizzare solo i <b>costi aggiuntivi selezionati</b> del":	$messaggio = "kommer kunna anv&auml;nda endast <b>valda extrakostnader</b> f&ouml;r"; break;
case "Verranno cambiati i <b>costi aggiuntivi</b> da utilizzare per l'anno":	$messaggio = "<b>Valda extrakostnader</b> kommer &auml;ndras f&ouml;r &aring;r"; break;
case "potrà visualizzare <b>tutti i documenti</b> del":	$messaggio = "kommer kunna se <b>alla dokument</b> f&ouml;r"; break;
case "potrà visualizzare solo i <b>documenti selezionati</b> del":	$messaggio = "kommer kunna se endast <b>valda dokument</b> f&ouml;r"; break;
case "Verranno cambiati i <b>documenti</b> visualizzabili per l'anno":	$messaggio = "<b>Valda dokument</b> kommer &auml;ndras f&ouml;r &aring;r"; break;
case "non potrà inserire <b>nuove prenotazioni</b> nel":	$messaggio = "kommer inte kunna infoga <b>nya bokningar</b> under"; break;
case "potrà inserire <b>nuove prenotazioni</b> nel":	$messaggio = "kommer kunna infoga <b>nya bokningar</b> under"; break;
case "non potrà <b>confermare</b> le nuove prenotazioni inserite nel":	$messaggio = "kommer inte kunna <b>bekr&auml;fta</b> nya bokningar infogade under"; break;
case "potrà <b>confermare</b> le nuove prenotazioni inserite nel":	$messaggio = "kommer kunna <b>bekr&auml;fta</b> nya bokningar infogade under"; break;
case "non potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer inte kunna infoga en <b>rabatt</b> n&auml;r nya bokningar infogas under"; break;
case "potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer kunna infoga en <b>rabatt</b> n&auml;r nya bokningar infogas under"; break;
case "non potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer inte kunna infoga <b>extrakostnader</b> n&auml;r nya bokningar infogas under"; break;
case "potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer kunna infoga <b>extrakostnader</b> n&auml;r nya bokningar infogas under"; break;
case "non potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer inte kunna infoga <b>antal personer</b> n&auml;r nya bokningar infogas under"; break;
case "potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer kunna infoga <b>antal personer</b> n&auml;r nya bokningar infogas under"; break;
case "non potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "kommer inte kunna infoga nya bokningar under <b>redan p&aring;b&ouml;rjade perioder</b> under"; break;
case "potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "kommer kunna infoga bokningar under <b>redan p&aring;b&ouml;rjade perioder</b> under"; break;
case "non potrà modificare <b>nessuna prenotazione</b> nel":	$messaggio = "kommer inte kunna &auml;ndra <b>n&aring;gra bokningar</b> under"; break;
case "potrà modificare solo le <b>sue prenotazioni</b> nel":	$messaggio = "kommer kunna &auml;ndra endast hans/hennes<b>egna bokningar</b> under"; break;
case "potrà modificare solo le <b>sue prenotazioni</b> e quelle di utenti appartenenti ai suoi gruppi nel":	$messaggio = "kommer kunna &auml;ndra endast hans/hennes <b>egna bokningar</b> samt dom som &auml;gs av anv&auml;ndare h&ouml;rande till hans grupper under"; break;
case "potrà modificare <b>tutte le prenotazioni</b> nel":	$messaggio = "kommer kunna &auml;ndra <b>alla bokningar</b> under"; break;
case "non potrà modificare la <b>data iniziale o finale</b> delle prenotazioni nel":	$messaggio = "kommer inte kunna &auml;ndra <b>start- eller slutdatum</b> f&ouml;r bokningar under"; break;
case "potrà modificare la <b>data iniziale o finale</b> delle prenotazioni nel":	$messaggio = "kommer kunna &auml;ndra <b>start- eller slutdatum</b> f&ouml;r bokningar under"; break;
case "non potrà modificare la <b>tariffa</b> delle prenotazioni nel":	$messaggio = "kommer inte kuna &auml;ndra <b>priset</b> f&ouml;r bokningar under"; break;
case "potrà modificare la <b>tariffa</b> delle prenotazioni, scegliendo se utilizzare la regola 2, nel":	$messaggio = "kommer kunna &auml;ndra <b>priset</b> f&ouml;r bokningar, v&auml;ljandes om regel 2 ska anv&auml;ndas, under"; break;
case "non potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "kommer inte kunna &auml;ndra <b>antalet personer</b> f&ouml;r bokningar under"; break;
case "potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "kommer kunna &auml;ndra <b>antalet personer</b> f&ouml;r bokningar under"; break;
case "non potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "kommer inte kunna &auml;ndra <b>kommentaren</b> f&ouml;r bokningar under"; break;
case "potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "kommer kunna &auml;ndra <b>kommentaren</b> f&ouml;r bokningar under"; break;
case "non potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "kommer inte kuna &auml;ndra <b>rabatten</b> f&ouml;r bokningar under"; break;
case "potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "kommer kunna &auml;nda <b>rabatten</b> f&ouml;r bokningar under"; break;
case "non potrà modificare i <b>costi aggiuntivi</b> delle prenotazioni nel":	$messaggio = "kommer inte kunna &auml;ndra <b>extrakostnaderna</b> f&ouml;r bokningar under"; break;
case "potrà modificare i <b>costi aggiuntivi</b> delle prenotazioni nel":	$messaggio = "kommer kunna &auml;ndra <b>extrakostnaderna</b> f&ouml;r bokningar under"; break;
case "non potrà modificare i <b>soldi pagati</b> e la <b>conferma</b> delle prenotazioni nel":	$messaggio = "kommer inte kunna &auml;ndra det <b>betalda beloppet</b> och <b>bekr&auml;ftelsen</b> f&ouml;r bokningar under"; break;
case "non potrà modificare i <b>soldi pagati</b> ma solo la <b>conferma</b> delle prenotazioni nel":	$messaggio = "kommer inte kunna &auml;ndra det <b>betalda beloppet</b> men d&auml;remot <b>bekr&auml;ftelsen</b> f&ouml;r bokningar under"; break;
case "potrà modificare i <b>soldi pagati</b> e la <b>conferma</b> delle prenotazioni nel":	$messaggio = "kommer kunna &auml;ndra det <b>betalda beloppet</b> och <b>bekr&auml;ftelsen</b> f&ouml;r bokningar under"; break;
case "non potrà modificare le <b>prenotazioni già iniziate</b> nel":	$messaggio = "kommer inte kunna &auml;ndra <b>redan p&aring;b&ouml;rjade bokningar</b> under"; break;
case "potrà modificare anche le <b>prenotazioni già iniziate</b> nel":	$messaggio = "kommer kunna &auml;ndra &auml;ven <b>redan p&aring;b&ouml;rjade bokningar</b> under"; break;
case "non avrà <b>limite di tempo</b> per modificare le prenotazioni nel":	$messaggio = "kommer inte ha n&aring;gon <b>tidsgr&auml;ns</b> f&ouml;r att &auml;ndra bokningar"; break;
case "non potrà più modificare le prenotazioni <b>dopo":	$messaggio = "kommer inte kunna &auml;ndra bokningar l&auml;ngre <b>efter"; break;
case "non potrà <b>cancellare</b> nessuna prenotazione nel":	$messaggio = "kommer inte kunna <b>ta bort</b> bokningar under"; break;
case "potrà <b>cancellare</b> tutte le prenotazioni nel":	$messaggio = "kommer kunna <b>ta bort</b> alla bokningar under"; break;
case "non avrà <b>limite di tempo</b> per cancellare le prenotazioni nel":	$messaggio = "kommer inte ha n&aring;gon <b>tidsgr&auml;ns</b> f&ouml;r att ta bort bokningar"; break;
case "ore</b> nel":  				$messaggio = "timmar</b> under"; break;
case "non potrà più cancellare le prenotazioni <b>dopo":	$messaggio = "kommer inte kunna ta bort bokningar l&auml;ngre <b>efter"; break;
case "non potrà inserire le <b>spese</b> nel":	$messaggio = "kommer inte kunna infoga <b>betalningar</b> under"; break;
case "potrà inserire le <b>spese</b> nel":  	$messaggio = "kommer kunna infoga <b>betalningar</b> under"; break;
case "non potrà inserire le <b>entrate</b> nel":	$messaggio = "kommer inte kunna infoga <b>kvitton</b> under"; break;
case "potrà inserire le <b>entrate</b> nel":	$messaggio = "kommer kunna infoga <b>kvitton</b> under"; break;
case "Le entrate inserite non verranno mai <b>sottratte</b> dal totale delle prenotazioni nel":	$messaggio = "Infoga kvitton kommer aldrig <b>subtraheras</b> fr&aring;n bokningstotalen under"; break;
case "potrà decidere se <b>sottrarre</b> le entrate dal totale delle prentazioni nel":	$messaggio = "komemr kunna <b>subtrahera</b> kvitton fr&aring;n bokningstotalen under"; break;
case "Le entrate inserite verranno sempre <b>sottratte</b> dal totale delle prenotazioni nel":	$messaggio = "Infogade kvitton kommer alltid <b>subtraheras</b> fr&aring;n bokningstotalen under"; break;
case "Non verrà inserito nessuno come <b>persona</b> che inserisce le spese o le entrate nel":	$messaggio = "Ingen kommer infogas som <b>personen</b> som infogar kvitton och betalningar under"; break;
case "potrà scegliere chi inserire come <b>persona</b> che inserisce le spese e le entrate nel":	$messaggio = "kommer kunna v&auml;lja vem som ska infogas som <b>personen</b> som infogar kvitton och betalningar under"; break;
case "Verrà sempre inserito il nome dell'utente":	$messaggio = "Kommer alltid infogas anv&auml;ndarnamnet"; break;
case "come <b>persona</b> che inserisce le spese e le entrate nel": 	$messaggio = "som <b>personen</b> som infogar kvitton och betalningar under"; break;
case "non potrà vedere le <b>tabelle dei mesi</b> del":	$messaggio = "kommer inte kunna se <b>m&aring;nadstabellerna</b> f&ouml;r"; break;
case "nelle <b>tabelle dei mesi</b> del":  	$messaggio = "i <b>m&aring;nadstabellerna</b> f&ouml;r"; break;
case "potrà vedere le <b>tabelle dei mesi</b> del":	$messaggio = "kommer kunna se <b>m&aring;nadstabellerna</b> f&ouml;r"; break;
case "non potrà vedere la <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "kommer inte kunna se <b>bokningstabellen</b> f&ouml;r"; break;
case "potrà vedere solo le proprie prenotazioni nella <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "kommer kunna se endast hans/hennes egna bokningar i <b>bokningstabellen</b> f&ouml;r"; break;
case "potrà vedere solo le prenotazioni sue e di utenti appartenenti ai suoi gruppi nella <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "kommer kunna se endast bokningar fr&aring;n honom/henne och fr&aring;n anv&auml;ndare h&ouml;rande till hans/hennes grupper i <b>bokningstabellen</b> f&ouml;r"; break;
case "potrà vedere la <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "kommer kunna se <b>bokningstabellen</b> f&ouml;r"; break;
case "non potrà vedere le <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "kommer inte kunna se <b>tabellen med kvitton och betalningar</b> f&ouml;r"; break;
case "potrà vedere solo le proprie entrate/uscite nelle <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "kommer kunna se endast hans/hennes egna kvitton/betalningar i <b>tabellen med kvitton och betalningar</b> f&ouml;r"; break;
case "potrà vedere solo le entrate/uscite sue e di utenti appartenenti ai suoi gruppi nelle <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "kommer kunna se endast kvitton/betalningar fr&aring;n honom/henne och fr&aring;n anv&auml;ndare h&ouml;rande till hans/hennes grupper i <b>tabellen med kvitton och betalningar</b> f&ouml;r"; break;
case "potrà vedere le <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "kommer kunna se <b>tabellen med kvitton och betalningar</b> f&ouml;r"; break;
case "non potrà vedere la <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "kommer inte kunna se <b>tabellen med perioder och priser</b> f&ouml;r"; break;
case "potrà vedere solo le tariffe a lui consentite nella <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "kommer kunna se endast priser till&aring;tna f&ouml;r honom/henne i <b>tabellen med perioder och priser</b> f&ouml;r"; break;
case "potrà vedere solo le tariffe consentite a lui e ad utenti dei suoi gruppi nella <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "kommer kunna se endast priser till&aring;tna f&ouml;r honom/henne och f&ouml;r anv&auml;ndare h&ouml;rande till hans/hennes grupper i <b>tabellen med perioder och priser</b> f&ouml;r"; break;
case "potrà vedere la <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "kommer kunna se <b>tabellen med perioder och priser</b> f&ouml;r"; break;
case "non potrà vedere la <b>tabella con le regole di assegnazione</b> del":	$messaggio = "kommer inte kunna se <b>tabellen med &ouml;verl&aring;telseregler</b> f&ouml;r"; break;
case "potrà vedere solo le regole a lui consentite nella <b>tabella con le regole di assegnazione</b> del":	$messaggio = "kommer kunna se endast regler till&aring;tna f&ouml;r honom/henne i <b>tabellen med &ouml;verl&aring;telseregler</b> f&ouml;r"; break;
case "potrà vedere solo le regole consentite a lui e ad utenti dei suoi gruppi nella <b>tabella con le regole di assegnazione</b> del":	$messaggio = "kommer kunna se endast regler till&aring;tna f&ouml;r honom/henne och f&ouml;r anv&auml;ndare h&ouml;rande till hans/hennes grupper i <b>tabellen med &ouml;verl&aring;telseregler</b> f&ouml;r"; break;
case "potrà vedere la <b>tabella con le regole di assegnazione</b> del":	$messaggio = "kommer kunna se <b>tabellen med &ouml;verl&aring;telseregler</b> f&ouml;r"; break;
case "Possibilità di inserire più prenotazioni contemporaneamente":	$messaggio = "M&ouml;jlighet att infoga fler bokningar samtidigt"; break;
case "non potrà inserire <b>più prenotazioni contemporaneamente</b> nel":	$messaggio = "kommer inte kunna infoga <b>fler bokningar samtidigt</b> under"; break;
case "potrà inserire <b>più prenotazioni contemporaneamente</b> nel":	$messaggio = "kommer kunna infoga <b>fler bokningar samtidigt</b> under"; break;
case "Prenotazioni non più cancellabili dopo essere state confermate":	$messaggio = "Bokningar inte borttagningsbara l&auml;ngre efter att ha blivit bekr&auml;ftade"; break;
case "non potrà <b>cancellare</b> le prenotazioni confermate nel":	$messaggio = "kommer inte kunna <b>ta bort</b> bekr&auml;ftade bokningar under"; break;
case "potrà <b>cancellare</b> le prenotazioni confermate nel":	$messaggio = "kommer kunna <b>ta bort</b> bekr&auml;ftade bokningar under"; break;
case "Possibilità di modificare l'orario di entrata ed uscita":	$messaggio = "M&ouml;jlighet att &auml;ndra in- och utcheckningstider"; break;
case "non potrà modificare l'orario di <b>entrata ed uscita</b> delle prenotazioni nel":	$messaggio = "kommer inte kunna &auml;ndra <b>in- och utcheckningstider</b> f&ouml;r bokningar under"; break;
case "potrà modificare l'orario di <b>entrata ed uscita</b> delle prenotazioni nel":	$messaggio = "kommer kunna &auml;ndra <b>in- och utcheckningstider</b> f&ouml;r bokningar under"; break;
case "Possibilità di vedere i messaggi ricevuti":	$messaggio = "M&ouml;jlighet att se mottagna meddelanden"; break;
case "Possibilità di mandare messaggi":  	$messaggio = "M&ouml;jlighet att se meddelanden"; break;
case "non potrà vedere <b>i messaggi ricevuti</b>":	$messaggio = "kommer inte kunna se <b>mottagna meddelanden</b>"; break;
case "potrà vedere <b>i messaggi ricevuti</b>":	$messaggio = "kommer kunna se <b>mottagna meddelanden</b>"; break;
case "non potrà <b>inviare messaggi</b>":	$messaggio = "kommer inte kunna <b>s&auml;nda meddelanden</b>"; break;
case "potrà <b>inviare messaggi</b>":  		$messaggio = "kommer kunna <b>s&auml;nda meddelanden</b>"; break;
case "Possibilità di inserire l'orario di entrata":	$messaggio = "M&ouml;jlighet att infoga incheckningstid"; break;
case "non potrà inserire l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer inte kunna &auml;ndra <b>incheckningstiden</b> n&auml;r nya bokningar infogas under"; break;
case "potrà inserire la l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer kunna &auml;ndra <b>incheckningstiden</b> n&auml;r nya bokningar infogas under"; break;
case "non potrà vedere e modificare il <b>codice prenotazione</b> nel":	$messaggio = "kommer inte kunna se och &auml;ndra <b>bokningskoden</b> under"; break;
case "potrà vedere e modificare il <b>codice prenotazione</b> nel":	$messaggio = "kommer kunna se och &auml;ndra <b>bokningskoden</b> under"; break;
case "Possibilità di vedere e modificare il codice prenotazione":	$messaggio = "M&ouml;jlighet att se och &auml;ndra bokningskoden"; break;
case "Possibilità di cambiare il cliente con un altro":	$messaggio = "M&ouml;jlighet att &auml;ndra kunden till en annan"; break;
case "potrà cambiare il <b>cliente</b> delle prenotazioni nel":	$messaggio = "kommer kunna &auml;ndra <b>kunden</b> f&ouml;r bokningen under"; break;
case "non potrà cambiare il <b>cliente</b> delle prenotazioni nel":	$messaggio = "kommer inte kunna &auml;ndra <b>kunden</b> f&ouml;r bokningen under"; break;
case "potrà inserire <b>più prenotazioni contemporaneamente ma non vicine</b> nel":	$messaggio = "kommer kunna infoga <b>flera bokningar samtidigt men inte i n&auml;rliggande rum</b> under"; break;
case "Possibilità di modificare le prenotazioni vicine":	$messaggio = "M&ouml;jlighet att &auml;ndra n&auml;rliggande bokningar"; break;
case "non potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "kommer inte kuna &auml;ndra <b>n&auml;rliggande bokningar</b> under"; break;
case "potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "kommer kunna &auml;ndra <b>n&auml;rliggande bokningar</b> under"; break;
case "Possibilità di inserire l'origine":  	$messaggio = "M&ouml;jlighet att infoga ursprung"; break;
case "Possibilità di modificare l'origine":  	$messaggio = "M&ouml;jlighet att &auml;ndra ursprunget"; break;
case "potrà inserire <b>l'origine della prenotazione</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer kunna infoga <b>bokningsursprung</b> n&auml;r nya bokningar infogas under"; break;
case "non potrà inserire <b>l'origine della prenotazione</b> quando inserisce nuove prenotazioni nel":	$messaggio = "kommer inte kunna infoga <b>bokningsursprung</b> n&auml;r nya bokningar infogas under"; break;
case "potrà modificare il <b>l'origine</b> delle prenotazioni nel":	$messaggio = "kommer kunna &auml;ndra <b>ursprunget</b> f&ouml;r bokningar under"; break;
case "non potrà modificare <b>l'origine</b> delle prenotazioni nel":	$messaggio = "kommer inte kunna &auml;ndra <b>ursprunget</b> f&ouml;r bokningar under"; break;
case "Possibilità di modificare le <i>tariffe</i> a lui permesse":	$messaggio = "M&ouml;jlighet att &auml;ndra <i>priserna</i> till&aring;tna f&ouml;r honom/henne"; break;
case "Possibilità di inserire <i>nuovi costi aggiuntivi</i>":	$messaggio = "M&ouml;jlighet att infoga <i>nya extrakostnader"; break;
case "rendendoli disponibili":			$messaggio = "och g&ouml;r dom till&auml;ngliga"; break;
case "solo a lui":  				$messaggio = "endast f&ouml;r honom/henne"; break;
case "a utenti dei suoi gruppi":  		$messaggio = "f&ouml;r anv&auml;ndare fr&aring;n hans/hennes grupper"; break;
case "Possibilità di modificare i <i>costi aggiuntivi</i> a lui permessi":	$messaggio = "M&ouml;jlighet att &auml;ndra <i>extrakostnaderna</i> till&aring;tna f&ouml;r honom/henne"; break;
case "non potrà modifcare le <b>tariffe a lui permesse</b> nel":	$messaggio = "kommer inte kunna &auml;ndra <b>priserna till&aring;tna f&ouml;r honom/henne</b> under"; break;
case "potrà modifcare le <b>tariffe a lui permesse</b> nel":	$messaggio = "kommer kunna &auml;ndra <b>priserna till&aring;tna f&ouml;r honom/henne</b> under"; break;
case "non potrà inserire <b>nuovi costi aggiuntivi</b> nel":	$messaggio = "kommer inte kunna infoga <b>nya extrakostnader</b> under"; break;
case "potrà inserire <b>nuovi costi aggiuntivi</b> il cui utilizzo sarà permesso a lui e agli utenti appartenenti ai suoi stessi gruppi nel":	$messaggio = "kommer kunna infoga <b>nya extrakostnader</b> vars anv&auml;ndande kommer bli till&aring;tet f&ouml;r honom/henne och f&ouml;r anv&auml;ndare h&ouml;rande till hans/hennes grupper under"; break;
case "potrà inserire <b>nuovi costi aggiuntivi</b> il cui utilizzo sarà permesso solo a lui nel":	$messaggio = "kommer kunna infoga <b>nya extrakostnader</b> vars anv&auml;ndande kommer vara till&aring;tet bara f&ouml;r honom/henne"; break;
case "non potrà modifcare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "Kommer inte kunna &auml;ndra <b>extrakostnaderna till&aring;tna f&ouml;r honom/henne</b> under"; break;
case "potrà modifcare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "kommer kunna ndra <b>extrakostnaderna till&aring;tna f&ouml;r honom/henne</b> under"; break;
case "Possibilità di cancellare i <i>costi aggiuntivi</i> a lui permessi":	$messaggio = "M&ouml;jlighet att ta bort <i>extrakostnaderna</i> till&aring;tna f&ouml;r honom/henne"; break;
case "non potrà cancellare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "kommer inte kunna ta bort <b>extrakostnaderna till&aring;tna f&ouml;r honom/henne</b> under"; break;
case "potrà cancellare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "kommer kunna ta bort <b>extrakostnaderna till&aring;tna f&ouml;r honom/henne</b> under"; break;
case "nelle <b>statistiche</b> del":  		$messaggio = "i <b>statistiken</b> f&ouml;r"; break;
case "non potrà vedere le <b>statistiche</b> del":	$messaggio = "kommer inte kunna se <b>statistiken</b> f&ouml;r"; break;
case "potrà vedere le <b>statistiche</b> del":	$messaggio = "kommer kunna se <b>statistiken</b> f&ouml;r"; break;
case "Possibilità di vedere <i>le statistiche</i>":	$messaggio = "M&ouml;jlighet att se <i>statistiken</i>"; break;
case "Possibilità di vedere i <i>beni dell'inventario</i>":	$messaggio = "M&ouml;jlighet att se <i>inventorief&ouml;rem&aring;l</i>"; break;
case "Possibilità di inserire nuovi beni nell'inventario":	$messaggio = "M&ouml;jlighet att infoga nya inventorief&ouml;rem&aring;l"; break;
case "Possibilità di vedere l'<i>inventario dei magazzini</i>":	$messaggio = "M&ouml;jlighet att se <i>f&ouml;rr&aring;dsrumsinventarium</i>"; break;
case "Possibilità di inserire nuovi magazzini":	$messaggio = "M&ouml;jlighet att infoga nya f&ouml;rr&aring;dsrum"; break;
case "Possibilità di aggiungere e cancellare beni":	$messaggio = "M&ouml;jlighet att l&auml;gga till och ta bort f&ouml;rem&aring;l"; break;
case "Solo in":  				$messaggio = "Endast i"; break;
case "magazzini propri":  			$messaggio = "egna f&ouml;rr&aring;dsrum"; break;
case "magazzini dei suoi gruppi":  		$messaggio = "f&ouml;rr&aring;dsrum fr&aring;n hans/hennes grupper"; break;
case "Possibilità di modificare le quantità dei beni":	$messaggio = "M&ouml;jlighet att &auml;ndra f&ouml;rem&aring;lskvantitet"; break;
case "non potrà vedere i <b>beni dell'inventario</b>":	$messaggio = "kommer inte kunna se <b>inventorief&ouml;rem&aring;l</b>"; break;
case "potrà vedere solo i <b>suoi beni dell'inventario</b>":	$messaggio = "kommer kunna se endast <b>hans/hennes inventorief&ouml;rem&aring;l</b>"; break;
case "potrà vedere i <b>beni dell'inventario</b>":	$messaggio = "kommer kunna se <b>inventorief&ouml;rem&aring;len</b>"; break;
case "non potrà <b>inserire nuovi beni</b> nell'inventario":	$messaggio = "kommer inte kunna <b>infoga nya f&ouml;rem&aring;l</b> i inventorium"; break;
case "potrà <b>inserire nuovi beni</b> nell'inventario":	$messaggio = "kommer kunna <b>infoga nya f&ouml;rem&aring;l</b> i inventorium"; break;
case "non potrà vedere <b>l'inventario":  	$messaggio = "kommer inte kunna se <b>inventoriet"; break;
case "potrà vedere <b>l'inventario":  		$messaggio = "kommer kunna se <b>inventoriet"; break;
case "dei magazzini</b>":  			$messaggio = "f&ouml;r f&ouml;rr&aring;dsrum</b>"; break;
case "solo dei suoi magazzini</b>":  		$messaggio = "endast f&ouml;r hans/hennes egna f&ouml;rr&aring;dsrum</b>"; break;
case "e di quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "och f&ouml;r dom fr&aring;n anv&auml;ndare h&ouml;rande till hans/hennes grupper"; break;
case "non potrà <b>inserire nuovi magazzini</b>":	$messaggio = "kommer inte kunna <b>infoga nya f&ouml;rr&aring;dsrum</b>"; break;
case "potrà <b>inserire nuovi magazzini</b>":	$messaggio = "kommer kunna <b>infoga nya f&ouml;rr&aring;dsrum</b>"; break;
case "non potrà <b>aggiungere e cancellare beni</b>":	$messaggio = "kommer inte kunna <b>l&auml;gga till eller ta bort f&ouml;rem&aring;l</b>"; break;
case "potrà <b>aggiungere e cancellare beni</b>":	$messaggio = "kommer kunna <b>l&auml;gga till eller ta bort f&ouml;rem&aring;l</b>"; break;
case "nei magazzini":  				$messaggio = "i f&ouml;rr&aring;dsrum"; break;
case "solo nei suoi magazzini":  		$messaggio = "endast i hans/hennes egna f&ouml;rr&aring;dsrum"; break;
case "e in quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "och i dom fr&aring;n anv&auml;ndare h&ouml;rande till hans/hennes grupper"; break;
case "non potrà <b>modificare le quantità dei beni</b>":	$messaggio = "kommer inte kunna <b>&auml;ndra f&ouml;rem&aring;lskvantitet</b>"; break;
case "potrà <b>modificare le quantità dei beni</b>":	$messaggio = "kommer kunna <b>&auml;ndra f&ouml;rem&aring;lskvantitet</b>"; break;
case "nel":  					$messaggio = "in"; break;
case "Possibilità di inserire la caparra e le commissioni":	$messaggio = "Possibility to insert deposit and commissions"; break;
case "Possibilità di inserire il commento":  	$messaggio = "Possibility to insert the comment"; break;
case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Possibility to insert custom comments"; break;
case "Possibilità di vedere il commento":  	$messaggio = "Possibility to view the comment"; break;
case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Possibility to view and modify custom comments"; break;
case "Possibilità di modificare la caparra e le commissioni":  	$messaggio = "Possibility to modify deposit and commissions"; break;
case "non potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
case "potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>comment</b> when inserts new reservations in"; break;
case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>comment</b> when inserts new reservations in"; break;
case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>custom comments</b> when inserts new reservations in"; break;
case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>custom comments</b> when inserts new reservations in"; break;
case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to view the <b>comment</b> of reservations in"; break;
case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to view the <b>comment</b> of reservations in"; break;
case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will not be able to view and modify <b>custom comments</b> of reservations in"; break;
case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will be able to view and modify <b>custom comments</b> of reservations in"; break;
case "non potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>deposit</b> and the <b>commissions</b> of reservations in"; break;
case "potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>deposit</b> and the <b>commissions</b> of reservations in"; break;
case "potrà <b>cancellare</b> solo le prenotazioni non iniziate nel":	$messaggio = "will be able to <b>delete</b> only not begun reservations in"; break;
case "creazione, download e cancellazione del backup completo":	$messaggio = "create, download and delete the complete backup"; break;
case "potrà creare i <b>backup</b>":  		$messaggio = "will be able to create <b>backups</b>"; break;
case "non potrà più creare i <b>backup</b>":  	$messaggio = "will not be able to create <b>backups</b>"; break;
case "Possibilità di vedere la <i>tabella con i documenti salvati</i>":	$messaggio = "Possibility to view the <i>table with saved documents</i>"; break;
case "Solo con documenti consentiti":  		$messaggio = "Only with documents permitted"; break;
case "non potrà vedere la <b>tabella con i documenti salvati</b> del":	$messaggio = "will not be able to view the <b>table with saved documents</b> of"; break;
case "potrà vedere solo i documenti a lui consentiti nella <b>tabella con i documenti salvati</b> del":	$messaggio = "will be able to view only documents permitted to him in the <b>table with saved documents</b> of"; break;
case "potrà vedere la <b>tabella con i documenti salvati</b> del":	$messaggio = "will be able to view the <b>table with saved documents</b> of"; break;
case "Permetti l'uso solo delle <i>casse</i> selezionate":	$messaggio = "Permit the usage of selected <i>cashboxes</i> only"; break;
case "Permetti l'uso di tutte le <i>casse</i>":	$messaggio = "Permit the usage of all <i>cashboxes</i>"; break;
case "cassa principale":  			$messaggio = "main cashbox"; break;
case "potrà usare <b>tutte le casse</b>":  	$messaggio = "will be able to use <b>all cashboxes</b>"; break;
case "potrà usare solo le <b>casse selezionate</b>":	$messaggio = "will be able to use only <b>selected cashboxes</b>"; break;
case "Verranno cambiate le <b>casse</b> utilizzabili":	$messaggio = "The <b>cashboxes</b> that can be used will be changed"; break;
case "Inserire sempre i pagamenti delle prenotazioni nella cassa":	$messaggio = "Always insert reservations payments in cashbox"; break;
case "I pagamenti inseriti nelle prenotazioni dall'utente":	$messaggio = "Payments inserted in reservations by user"; break;
case "verranno anche registrati come entrate nella cassa chiamata":	$messaggio = "will be also registered as incomes in cashbox called"; break;
case "non verranno registrati in cassa nel":	$messaggio = "will not be registered in any cashbox in"; break;
case "Modifica dei documenti":  		$messaggio = "Modify documents"; break;
case "potrà modificare i <b>documenti</b>":  	$messaggio = "will be able to modify <b>documents</b>"; break;
case "non potrà più modificare i <b>documenti</b>":	$messaggio = "will not be able to modify <b>documents</b> anymore"; break;
case "Possibilità di vedere email, telefoni e fax dei clienti":	$messaggio = "Possibility to view emails, telephones and faxes of clients"; break;
case "Possibilità di vedere l'indirizzo dei clienti":	$messaggio = "Possibility to view the address of clients"; break;
case "potrà vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "will be able to view <b>emails, telephones and faxes</b> of clients"; break;
case "non potrà più vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "will not be able to view <b>emails, telephones and faxes</b> of clients"; break;
case "potrà vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "will be able to view <b>the address</b> of clients"; break;
case "non potrà più vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "will not be able to view <b>the address</b> of clients"; break;
case "Mostrare le prenotazioni non permesse come":	$messaggio = "Show not permitted reservations as"; break;
case "oscurate":  				$messaggio = "obscured"; break;
case "periodi vuoti":  				$messaggio = "empty periods"; break;
case "solo correnti e future":  		$messaggio = "only current and future"; break;
case "vedrà le prenotazioni non permesse come <em>oscurate</em>":	$messaggio = "will see not permitted reservations as <em>obscured</em>"; break;
case "vedrà le prenotazioni non permesse come <em>periodi vuoti</em>":	$messaggio = "will see not permitted reservations as <em>empty periods</em>"; break;
case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed oscurate nel presente e nel futuro</em>":	$messaggio = "will see not permitted reservations as <em>empty periods in the past, obscured in the present and future</em>"; break;
case "Possibilità di cancellare o sovrascrivere i documenti salvati":	$messaggio = "Possibility to delete and overwrite saved documents"; break;
case "potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will be able to <b>delete and overwrite documents</b> saved in"; break;
case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will not be able to <b>delete and overwrite documents</b> saved in"; break;
case "Creazione e modifica delle interconnessioni":	$messaggio = "Create and modify interconnections"; break;
case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "will be able to create and modify <b>interconnections</b>"; break;
case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "will not be able to create and modify <b>interconnections</b>"; break;
case "Modifica dei documenti come API":  	$messaggio = "Modify documents as API"; break;
case "potrà modificare i <b>documenti come API</b>":	$messaggio = "will be able to modify <b>documents as API</b>"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "this can allow access to data of all reservations"; break;
case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "will not be able to modify <b>documents as API</b> anymore"; break;
case "Gestione della password per le carte di credito":	$messaggio = "Management of credit cards password"; break;
case "potrà gestire la <b>password per le carte di credito</b>":	$messaggio = "will be able to manage the <b>credit cards password</b>"; break;
case "non potrà più gestire la <b>password per le carte di credito</b>":	$messaggio = "will not be able to manage the <b>credit cards password</b>"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>